from django.urls import path
from . import views

app_name = 'polls'

urlpatterns = [
    path('', views.index, name='index'),
    #example : /polls/5
    path('<int:question_id>/', views.detail, name='detail'),
    #example : /polls/5/results
    path('<int:question_id>/results', views.results, name='results'),
    #example : /polls/5/votes
    path('<int:question_id>/votes', views.vote, name='votes'),
]   


from django.db import models

# Create your models here.

class Question(models.Model):
    def __str__(self):
        return self.question_text
    
    question_text = models.CharField(max_length=200)
    pub_date = models.DateTimeField('date published')


class Choice(models.Model):
    def __str__(self):
        return self.choice_text
    question = models.ForeignKey(Question, on_delete=models.CASCADE)
    choice_text = models.CharField(max_length=200)
    votes = models.IntegerField(default=0)